@@ -71,7 +71,7 @@ def parse_args(parser: argparse.ArgumentParser, args: List[str]) -> CliArgs:
 
 def parse_task_files(args: CliArgs) -> List[Task]:
     # Fetch Markdown task files
-    md_files = list(args.task_dir.glob("*.md"))
+    md_files = list(args.task_dir.glob("**/*.md"))
 
     # Parse each Markdown task file
     tasks_by_file: List[List[Task]] = [parse_markdown(file.read_text().split('\n'), today=args.today) for file in md_files]
@@ -108,7 +108,10 @@ def maybe_display_specific_task(args: CliArgs, tasks: List[Task], console: Conso
             console.print(Markdown(f"**Subtasks**:"))
         for subtask in task.subtasks:
             subtask_summary = task_summary(subtask, args.today)
-            console.print(Markdown(f"- {subtask.title} {subtask_summary}"))
+            if subtask.done:
+                console.print(Markdown(f"- **DONE**: {subtask.title} {subtask_summary}"))
+            else:
+                console.print(Markdown(f"- {subtask.title} {subtask_summary}"))
         if len(task.subtasks) > 0:
             console.print("")
 
@@ -119,13 +122,13 @@ def tasks_to_tree(args: CliArgs, tasks: List[Task]) -> Tree:
     # Print tasks as a tree
     tree = Tree(f"[bold underline]Tasks for today ({args.today})[/bold underline]" +
                 ("" if args.lookahead_days == timedelta(0) else f" (+{days(args.lookahead_days)})"))
-
     def add_to_tree(task: Task, tree: Tree, task_idx: int) -> Tree:
         if len(task.path) == 0:  # Base case
             parent = tree.add(Markdown(f"**{task_idx}** - {task.title} {task_summary(task, args.today)}"))
             if task.subtasks:
                 for subtask in task.subtasks:
-                    parent.add(Markdown(f"{subtask.title} {task_summary(subtask, args.today)}"))
+                    if subtask.done is False:
+                        parent.add(Markdown(f"{subtask.title} {task_summary(subtask, args.today)}"))
             return tree
         else:
             # Try to find the first heading in the current tree's children
